Structs
- Config
- The top-level YAML configuration structure.
- Custom
Channel - Configuration for
type: custom. - Desktop
Channel - Configuration for
type: desktop. - Loaded
Config - Fully-loaded config plus where it came from.
- Webhook
Channel - Configuration for
type: webhook.
Enums
- Channel
Config - A single channel definition.
- Config
Error - Config loading/validation failures.
- Init
Status - Result of running
brb init.
Functions
- config_
file_ path - Returns the absolute path to the global config file.
- init_
config - Creates a default global config file if it does not already exist.
- load_
config - Loads config from the global
config.ymland validates it. - load_
config_ from_ path - Loads and validates config from an explicit file path.
- validate_
config - Validates static schema and cross-field constraints.